@@ -47,8 +47,11 @@ def get_hybridview(newcls):
         def is_ajax(self):
             """Check the META HTTP_X_REQUESTED_WITH and CONTENT_TYPE"""
             meta = self.request.META
-            return meta.get('HTTP_X_REQUESTED_WITH') == 'XMLHttpRequest'\
-                or "json" in meta.get("CONTENT_TYPE")
+            requested_with = meta.get('HTTP_X_REQUESTED_WITH')
+            content_type = meta.get("CONTENT_TYPE")
+            if not requested_with or content_type:
+                return False
+            return requested_with == 'XMLHttpRequest' or "json" in content_type
 
         def render_to_response(self, context):
             cls = type(self).__bases__[self.is_ajax]
